@@ -26,8 +26,8 @@ class LogHistory(models.Model):
 class Token(models.Model):
     player: Player = models.OneToOneField(Player, on_delete=models.CASCADE)
 
-    access = models.CharField(max_length=32, null=True)
-    client = models.CharField(max_length=32, null=True)
+    access = models.UUIDField(null=True)
+    client = models.UUIDField(null=True)
     uuid = models.UUIDField(default=uuid4)
     server_id = models.CharField(max_length=48, null=True)
     created = models.DateTimeField(default=now)
