@@ -89,7 +89,7 @@ USE_TZ = True
 
 STATIC_URL = os.getenv('STATIC_URL', '/static/')
 STATIC_ROOT = os.getenv('STATIC_ROOT', os.path.join(BASE_DIR, 'lavender', 'static'))
-STATICFILES_DIRS = (os.path.join(BASE_DIR, 'lavender', 'frontend'),)
+STATICFILES_DIRS = ()
 
 LOGOUT_REDIRECT_URL = '/'
 
