@@ -34,3 +34,7 @@ def check_nickname(nickname: str):
         ))
 
     return result
+
+
+def texture_path_handler(instance, filename: str) -> str:
+    return f'{instance.token.uuid}/{filename}'
